package Exception::Multistate;
$Exception::Multistate::VERSION = '0.008';
use base qw(Exception);

1;
